ploneintranet.suite.tests package
=================================

Submodules
----------

ploneintranet.suite.tests.test_robot module
-------------------------------------------

.. automodule:: ploneintranet.suite.tests.test_robot
    :members:
    :undoc-members:
    :show-inheritance:

ploneintranet.suite.tests.test_setup module
-------------------------------------------

.. automodule:: ploneintranet.suite.tests.test_setup
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: ploneintranet.suite.tests
    :members:
    :undoc-members:
    :show-inheritance:
